Index: trunk/tools/drawing.py
===================================================================
--- trunk/tools/drawing.py	(revision 951)
+++ trunk/tools/drawing.py	(revision 952)
@@ -1780,6 +1780,6 @@
     draw_lines_time(ncfilens, values, varname):
       ncfilens= [filen] ',' separated list of netCDF files
-      values= [dimvname];[valuesaxis];[dimtit];[leglabels];[vtit];[title];[timevals];[locleg];
-        [graphk];[collines];[points];[linewidths];[pointsizes];[pointfreq];[period]
+      values= [dimvname];[valuesaxis];[dimtit];[leglabels];[vtit];[title];[rangevals];[timevals];
+        [legvals];[graphk];[collines];[points];[linewidths];[pointsizes];[pointfreq];[period]
         [dimvname]: ',' list of names of the variables with he values of the common dimension
         [valuesaxis]: which axis will be used for the values ('x', or 'y')
@@ -1788,4 +1788,7 @@
         [vartit]: name of the variable in the graph
         [title]: title of the plot ('|' for spaces)
+        [rangevals]: Range of the axis with the values ('None' for 'auto','auto')
+          [vmin],[vmax]: minimum and maximum values where [vmNN] can also be:
+            'auto': the computed minimumm or maximum of the values  
         [timevals]: [timen]|[units]|[kind]|[tfmt] time labels characteristics
            [timen]; name of the time variable
@@ -1831,6 +1834,7 @@
 
     expectargs = '[dimvname];[valuesaxis];[dimtit];[leglabels];[vtit];[title];'
-    expectargs = expectargs + '[timevals];[locleg];[graphk];[lines];[collines];[points];'
-    expectargs = expectargs + '[linewidths];[pointsizes];[pointfreq];[period]'
+    expectargs = expectargs + '[rangevals];[timevals];[legvals];[graphk];[lines];'
+    expectargs = expectargs + '[collines];[points];[linewidths];[pointsizes];'
+    expectargs - expectargs + '[pointfreq];[period]'
     drw.check_arguments(fname,values,expectargs,';')
 
@@ -1842,14 +1846,15 @@
     vartit = values.split(';')[4]
     title = values.split(';')[5].replace('|',' ')
-    timevals = values.split(';')[6]
-    legvalues = values.split(';')[7]
-    graphk = values.split(';')[8]
-    lines0 = values.split(';')[9]
-    collines0 = values.split(';')[10]
-    points0 = values.split(';')[11]
-    linewidths0 = values.split(';')[12]
-    pointsizes0 = values.split(';')[13]
-    pointfreq0 = values.split(';')[14]
-    period = values.split(';')[15]
+    rangevals = values.split(';')[6]
+    timevals = values.split(';')[7]
+    legvalues = values.split(';')[8]
+    graphk = values.split(';')[9]
+    lines0 = values.split(';')[10]
+    collines0 = values.split(';')[11]
+    points0 = values.split(';')[12]
+    linewidths0 = values.split(';')[13]
+    pointsizes0 = values.split(';')[14]
+    pointfreq0 = values.split(';')[15]
+    period = values.split(';')[16]
 
     Nfiles = len(ncfiles)
@@ -1928,4 +1933,13 @@
     timekind = timevals.split('|')[2]
     timefmt = timevals.split('|')[3]
+
+    if rangevals = 'None':
+        valmin = 'auto'
+        valmax = 'auto'
+    else:
+        valmin = rangevals.split(',')[0]
+        valmax = rangevals.split(',')[0]
+        if valmin != 'auto': valmin = np.float(valmin)
+        if valmax != 'auto': valmax = np.float(valmax)
 
     locleg = int(legvalues.split('|')[0])
@@ -2101,6 +2115,6 @@
 
     drw.plot_lines_time(dimvalues, varvalues, valuesaxis, dimtit, legvals, vartit,   \
-      varunits, timepos, timelabels, title, locleg, legfontsize, graphk, lines,      \
-      collines, points, linewidths, pointsizes, pointfreq)
+      varunits, timepos, timelabels, title, locleg, legfontsize, graphk, valmin,     \
+      valmax, lines, collines, points, linewidths, pointsizes, pointfreq)
 
     return
Index: trunk/tools/drawing_tools.py
===================================================================
--- trunk/tools/drawing_tools.py	(revision 951)
+++ trunk/tools/drawing_tools.py	(revision 952)
@@ -5731,5 +5731,5 @@
 
 def plot_lines_time(vardv, varvv, vaxis, dtit, linesn0, vtit, vunit, tpos, tlabs,    \
   gtit, gloc, gsize, kfig, lsl, coll, ptl, lwidth, psize, ptf):
     """ Function to plot a collection of lines with a time axis
       vardv= list of set of dimension values
@@ -5743,4 +5743,6 @@
       tlabs= labels of the time ticks
       gtit= main title
+      vmin= minimum value for the axis-value 'auto' for use the extreme
+      vmax= maximum value for the axis-value 'auto' for use the extreme
       gloc= location of the legend (0, autmoatic)
         1: 'upper right', 2: 'upper left', 3: 'lower left', 4: 'lower right',
@@ -5817,5 +5819,15 @@
 #        plt.xlim(np.min(varTvv),np.max(varTvv))
 #        plt.ylim(np.min(varTdv),np.max(varTdv))
-        plt.xlim(xtrmvv[0],xtrmvv[1])
+
+        if vmin == 'auto':
+            xmin = xtrmvv[0]
+        else:
+            xmin = vmin
+        if vmax == 'auto':
+            xmax = xtrmvv[1]
+        else:
+            xmax = vmax
+
+        plt.xlim(xmin,xmax)
         plt.ylim(xtrmdv[0],xtrmdv[1])
 
@@ -5852,6 +5864,15 @@
         plt.ylabel(vtit + ' (' + vunit + ')')
 
+        if vmin == 'auto':
+            ymin = xtrmvv[0]
+        else:
+            ymin = vmin
+        if vmax == 'auto':
+            ymax = xtrmvv[1]
+        else:
+            ymax = vmax
+
         plt.xlim(xtrmdv[0],xtrmdv[1])
-        plt.ylim(xtrmvv[0],xtrmvv[1])
+        plt.ylim(ymin,ymax)
 
 #        plt.xlim(np.min(varTdv),np.max(varTdv))
@@ -5731,5 +5731,5 @@
 
 def plot_lines_time(vardv, varvv, vaxis, dtit, linesn0, vtit, vunit, tpos, tlabs,    \
-  gtit, gloc, gsize, kfig, lsl, coll, ptl, lwidth, psize, ptf):
+  gtit, vmin, vmax, gloc, gsize, kfig, lsl, coll, ptl, lwidth, psize, ptf):
     """ Function to plot a collection of lines with a time axis
       vardv= list of set of dimension values
